<?php

namespace App\Models;

use Illuminate\Support\Collection;
use Illuminate\Support\Facades\DB;
use Jenssegers\Mongodb\Eloquent\Model;
use Jenssegers\Mongodb\Eloquent\SoftDeletes;

use App\Classes\FTN\Message;
use App\Interfaces\Packet;
use App\Traits\{EncodeUTF8,MsgID,UseMongo};

class Echomail extends Model implements Packet
{
	use SoftDeletes,MsgID,UseMongo,EncodeUTF8;

	protected $collection = FALSE;

	private const cast_utf8 = [
		'subject',
		'msg',
	];

	protected $dates = ['datetime'];

	/* RELATIONS */

	public function fftn()
	{
		return $this
			->setConnection('pgsql')
			->belongsTo(Address::class)
			->withTrashed();
	}

	/* ATTRIBUTES */

	public function getPathAttribute($value): Collection
	{
		return Address::whereIn('id',$value)
			->orderBy(DB::raw(sprintf("position (id::text in '(%s)')",join(',',$value))))
			->get()
			->pluck('ftn3d');
	}

	public function getSeenByAttribute($value): Collection
	{
		return Address::whereIn('id',$value)->get()->pluck('ftn2d');
	}

	/* METHODS */

	public function jsonSerialize(): array
	{
		return $this->encode();
	}

	/**
	 * Return this model as a packet
	 */
	public function packet(Address $ao): Message
	{
		// @todo Dont bundle mail to nodes that have been disabled, or addresses that have been deleted
		$o = new Message;

		$o->header = [
			'onode' => $this->fftn->node_id,
			'dnode' => $ao->node_id,
			'onet' => $this->fftn->host_id,
			'dnet' => $ao->host_id,
			'flags' => 0,	// @todo?
			'cost' => 0,
			'date'=>$this->datetime->format('d M y  H:i:s'),
		];

		$o->tzutc = $this->datetime->utcOffset($this->tzoffset)->getOffsetString('');
		$o->user_to = $this->to;
		$o->user_from = $this->from;
		$o->subject = $this->subject;
		$o->echoarea = $this->echoarea;
		$o->flags = $this->flags;

		$o->kludge->put('mid',$this->id);

		$o->msgid = $this->msgid;
		if ($this->reply)
			$o->reply = $this->reply;

		$o->message = $this->msg;

		if ($this->tagline)
			$o->tagline = $this->tagline;

		if ($this->tearline)
			$o->tearline = $this->tearline;

		if ($this->origin)
			$o->origin = $this->origin;

		// @todo SEENBY
		// @todo PATH

		return $o;
	}
}