@extends('layouts.app')

@section('htmlheader_title')
	@if($o->exists) Update @else Add @endif System
@endsection

@php
use App\Http\Controllers\DomainController as DC;
@endphp

@section('content')
	@if($o->exists)
		<h1>{{ $o->name }}@if($o->setup)<sup class="success" style="text-shadow: 0 0; font-size: 50%; top: -1em;">*</sup>@endif</h1>
		@if($o->setup)<sup class="success" style="float:right;top:-2em;">* This Host</sup>@endif
	@endif

	@if($o->zcs->count())
		<p>This system is the ZC for the following zones: <strong class="highlight">{!! $o->zcs->map(function($item) { return sprintf('%d@%s',$item->zone_id,$item->domain->name); })->join('</strong>, <strong class="highlight">') !!} </strong></p>
	@endif

	<div class="accordion accordion-flush" id="accordion_homepage">
		@if ($o->exists)
			<!-- System -->
			<div class="accordion-item">
				<h3 class="accordion-header" id="system" data-bs-toggle="collapse" data-bs-target="#collapse_system" aria-expanded="true" aria-controls="collapse_system">System</h3>

				<div id="collapse_system" class="accordion-collapse collapse {{ (! $flash=session()->pull('accordion')) ? 'show' : '' }}" aria-labelledby="system" data-bs-parent="#accordion_homepage">
					<div class="accordion-body">
						@include('system.form-system')
					</div>
				</div>
			</div>

			<!-- Addresses -->
			<div class="accordion-item">
				<h3 class="accordion-header" id="addresses" data-bs-toggle="collapse" data-bs-target="#collapse_addresses" aria-expanded="false" aria-controls="collapse_addresses">System AKAs</h3>

				<div id="collapse_addresses" class="accordion-collapse collapse {{ ($flash=='address') ? 'show' : '' }}" aria-labelledby="addresses" data-bs-parent="#accordion_homepage">
					<div class="accordion-body">
						<p>FidoNet addresses are constructed in the format <strong class="highlight">zone</strong>:<strong class="highlight">net</strong>/<strong class="highlight">node</strong>.<strong class="highlight">point</strong><span>@</span><strong class="highlight">domain</strong>.</p>

						<div class="accordion accordion-flush" id="accordion_ftnaddress">
							<h4 class="accordion-header" id="ftnaddress" data-bs-toggle="collapse" data-bs-target="#collapse_ftnaddresses" aria-expanded="false" aria-controls="collapse_addresses">Fidonet Addressing</h4>

							<div id="collapse_ftnaddresses" class="accordion-collapse collapse" aria-labelledby="ftnaddress" data-bs-parent="#accordion_ftnaddress">
								<div class="accordion-body">
									<p>FidoNet system are also assigned some roles, and in some cases, those roles have a particular address format:</p>
									<table class="table monotable">
										<thead>
										<tr>
											<th>Role</th>
											<th>Address Format</th>
										</tr>
										</thead>

										<tbody>
										<tr>
											<td>Zone <small>(optional)</small></td>
											<td>
												<strong class="highlight">ZONE</strong>:0/0.0, where the net, node and point values are zero. Zones normally have 1 or more Regions and/or Hosts.<br><br>
												<small>(Systems that do not configure other systems with a zone, assume that that other system is in the same zone as the system being configured.)</small>
											</td>
										</tr>
										<tr>
											<td>Region <small>(optional)</small></td>
											<td>
												zone:<strong class="highlight">REGION</strong>/0.0, where the zone indicates which zone the region is in. The node and point values are zero. Regions normally have 1 or more Hosts.<br><br>
												<small>Fidonet software normally doesnt configure the region address per-se. It is used by the mailer to receive packets destined to it by routing, in transition to the final destination. The region number must be unique with a zone.</small>
											</td>
										</tr>
										<tr>
											<td>Host <small>(mandatory)</small></td>
											<td>
												zone:<strong class="highlight">HOST</strong>/0.0, where the zone indicates which zone the host is in. The node and point values are zero. The Host system is normally configured with an additional address, where the NET address is the same and the NODE number that is greater than zero. Hosts may may zero or more Hubs and 1 or more Nodes.<br><br>
												<small>The host number must be unique within a zone, which implies that it cannot be the same as a region, if regions are used.</small>
											</td>
										</tr>
										<tr>
											<td>Hub <small>(optional)</small></td>
											<td>
												zone:net/<strong class="highlight">NODE</strong>.0, where the zone/net indicates which zone/net the hub is in. The system(s) in the nodelist below a Hub are fed from that hub from a routing perspective.<br><br>
												<small>The node is unique within the net and point is zero.</small>
											</td>
										</tr>
										<tr>
											<td>Node <small>(required)</small></td>
											<td>
												zone:net/<strong class="highlight">NODE</strong>.0, where the zone/net indicates which zone/net the node is in.<br><br>
												<small>The node is unique within the net and point is zero.</small>
											</td>
										</tr>
										</tbody>
									</table>
								</div>
							</div>
						</div>

						@if($o->addresses->count())
							<p>This system has the following addresses assigned to it:</p>

							<table class="table monotable">
								<thead>
								<tr>
									<th>Address</th>
									<th>Active</th>
									<th colspan="2">Role</th>
								</tr>
								</thead>

								<tbody>
								@foreach ($o->addresses->sortBy(function($item) { return sprintf('%04x%04x%04x%04x%04x',$item->zone->zone_id,$item->region_id,$item->host_id,$item->node_id,$item->point_id); }) as $oo)
									<tr>
										<td>{{ $oo->ftn }}</td>
										<td>{{ $oo->active ? 'YES' : 'NO' }}</td>
										<td>{{ $oo->role_name }}</td>
										<td class="nowrap actions">
											@can('admin',$oo)
												<a href="{{ url('ftn/system/susaddress',[$oo->id]) }}" title="@if($oo->active)Pause @else Activate @endif Address"><i class="bi @if($oo->active)bi-pause-circle-fill @else bi-play-circle-fill @endif"></i></a>
												{{--
													@if (! $oo->role & (DC::NODE_ZC|DC::NODE_RC|DC::NODE_NC))
														<a href="{{ url('ftn/system/modaddress',[$oo->id]) }}" title="Modify Address" class="modify"><i class="bi bi-pen-fill"></i></a>
													@endif
												--}}
												<a href="{{ url('ftn/system/movaddress',[$o->id,$oo->id]) }}" title="Move Address to another System"><i class="bi bi-arrow-right-square-fill"></i></a>
												<a href="{{ url('ftn/system/deladdress',[$oo->id]) }}" title="Delete Address" class="delete"><i class="bi bi-trash-fill"></i></a>
											@endcan
										</td>
									</tr>
								@endforeach
								</tbody>
							</table>
						@endif

						@can('admin',$o)
							@include('system.form-address')

						@else
							You'll need to ask an admin to assign addresses.
						@endcan
					</div>
				</div>
			</div>

			@if(! $o->setup)
				<!-- Authentication -->
				<div class="accordion-item">
					<h3 class="accordion-header" id="authentication" data-bs-toggle="collapse" data-bs-target="#collapse_auth" aria-expanded="false" aria-controls="collapse_auth">System Authentication</h3>

					<div id="collapse_auth" class="accordion-collapse collapse {{ ($flash=='session') ? 'show' : '' }}" aria-labelledby="authentication" data-bs-parent="#accordion_homepage">
						<div class="accordion-body">
							@if ($o->sessions->count())
								<table class="table monotable">
									<thead>
									<tr>
										<th colspan="2">&nbsp;</th>
										<th colspan="4" class="text-center">Passwords</th>
										<th>&nbsp;</th>
									</tr>
									<tr>
										<th>Zone</th>
										<th style="min-width: 1%;">Default</th>
										<th>Session</th>
										<th>Packet</th>
										<th>TIC</th>
										<th>Areafix</th>
										<th>&nbsp;</th>
									</tr>
									</thead>

									<tbody>
									@foreach ($o->sessions->sortBy('zone_id') as $oo)
									<tr>
										<td>{{ $oo->zone_id }}<span>@</span>{{ $oo->domain->name }}</td>
										<td style="text-align: center;">
											@if(($x=$oo->systems->where('pivot.default',TRUE))->count() && ($x->first()->id !== $o->id))
												<i class="bi bi-dash-square"></i>
											@else
												<span class="default" itemid="{{$oo->id}}"><i class="bi bi-{{ $x->count() ? 'check-square' : 'square' }}"></i></span>
											@endif
										</td>
										<td>{{ $oo->pivot->sespass }}</td>
										<td>{{ $oo->pivot->pktpass }}</td>
										<td>{{ $oo->pivot->ticpass }}</td>
										<td>{{ $oo->pivot->fixpass }}</td>
										<td style="width: 70px;">
											{{--
											<a href="{{ url('ftn/system/modsession',[$oo->id]) }}" title="Modify Details" class="modify"><i class="bi bi-pen-fill"></i></a>
											--}}
											<a href="{{ url('ftn/system/delsession',[$o->id,$oo->id]) }}" title="Delete Details" class="delete"><i class="bi bi-trash-fill"></i></a>
										</td>
									</tr>
									@endforeach
									</tbody>
								</table>
							@else
								<p>No session details exist</p>
							@endif

							@include('system.form-session')
						</div>
					</div>
				</div>

				<!-- Echoareas -->
				<div class="accordion-item">
					<h3 class="accordion-header" id="echoarea" data-bs-toggle="collapse" data-bs-target="#collapse_echoarea" aria-expanded="false" aria-controls="collapse_echoarea">Echo Area Subscription</h3>

					<div id="collapse_echoarea" class="accordion-collapse collapse {{ ($flash=='echoarea') ? 'show' : '' }}" aria-labelledby="echoarea" data-bs-parent="#accordion_homepage">
						<div class="accordion-body">
							<p>This system can subscribe to the following echoareas:</p>
							@include('system.form-echoarea')
						</div>
					</div>
				</div>

				<!-- Routing -->
				<div class="accordion-item">
					<h3 class="accordion-header" id="routing" data-bs-toggle="collapse" data-bs-target="#collapse_routing" aria-expanded="false" aria-controls="collapse_routing">Mail Routing</h3>

					<div id="collapse_routing" class="accordion-collapse collapse {{ ($flash=='routing') ? 'show' : '' }}" aria-labelledby="addresses" data-bs-parent="#accordion_homepage">
						<div class="accordion-body">
							<div class="row">
								<!-- Zone mail sent to -->
								<div class="col-6">
									@if(! $o->setup && ($x=\App\Models\Zone::active()
										->whereIn('id',$o->zones->pluck('id'))
										->whereNotIn('id',$o->sessions->pluck('id'))
										->get())->count())

										<h4>This host's mail is sent to:</h4>
										<table class="table monotable">
											<thead>
											<tr>
												<th>Zone</th>
												<th>System</th>
											</tr>
											</thead>

											<tbody>
											@foreach($x as $zo)
												@foreach ($o->match($zo) as $oo)
													<tr>
														<td>{{ $oo->ftn }}</td>
														<td>
															@if ($x=$oo->parent())
																{{ $x->ftn4d }}
															@else
																No destination for mail.
															@endif
														</td>
													</tr>
												@endforeach
											@endforeach
											</tbody>
										</table>
									@endif
								</div>

								<!-- Systems this host collects for -->
								<div class="col-6">
									<h4>This host collects mail for the following systems:</h4>

									@if($o->sessions->count())
										<table class="table monotable">
											<thead>
											<tr>
												<th>Zone</th>
												<th>System</th>
											</tr>
											</thead>

											<tbody>
											@foreach ($o->sessions->sortBy('zone_id') as $zo)
												@foreach ($o->match($zo) as $oo)
													<tr>
														<td>{{ $oo->ftn }}</td>
														<td>{!! (($x=$oo->children) && $x->count()) ? $x->pluck('ftn4d')->join('<br>') : 'None' !!}</td>
													</tr>
												@endforeach
											@endforeach
											</tbody>
										</table>
									@else
										<p>This host doesnt collect mail.</p>
									@endif
								</div>
							</div>
						</div>
					</div>
				</div>
			@endif
		@else
			@include('system.form-system')
		@endif
	</div>

	@include('widgets.modal_delete')
@endsection

@section('page-scripts')
	<script type="text/javascript">
		$(document).ready(function() {
			$('.default').click(function() {
				var item = this;
				icon = $(item).find('i');

				$.ajax({
					type: 'POST',
					data: {sid: {{$o->id}},_token: '{{csrf_token()}}',set:(icon.hasClass('bi-square') ? 1 : 0)},
					beforeSend: function() {
						$(item).find('i').addClass('spinner-grow spinner-grow-sm');
					},
					success: function() {
						if (icon.hasClass('bi-square')) {
							icon.removeClass('bi-square');
							icon.addClass('bi-check-square');
						} else {
							icon.removeClass('bi-check-square');
							icon.addClass('bi-square');
						}

						$(item).find('i').removeClass('spinner-grow spinner-grow-sm');
					},
					error: function(e) {
						$(item).find('i').removeClass('spinner-grow spinner-grow-sm');

						if (e.status != 412)
							alert('That didnt work? Please try again....');
					},
					url: '{{ url('api/default') }}/'+item.attributes.itemid.nodeValue,
					cache: false
				})
			});
		});
	</script>
@append